@@ -121,7 +121,7 @@ prone to change as a result of feedback.
           --rex_skip_source_file='{app_cpan_deps/}'
 
   #Post process to generate covered database
-  cover -report Html_basic
+  cover -report Html_basic  # Needs Template installed
 
 
 =head2 During development
@@ -252,10 +252,7 @@ efficiently.
 
 use strict;
 package Devel::CoverX::Covered;
-{
-  $Devel::CoverX::Covered::VERSION = '0.015';
-}
-
+$Devel::CoverX::Covered::VERSION = '0.016';
 
 
 
@@ -273,7 +270,7 @@ L<Devel::Cover>
 
 =head1 AUTHOR
 
-Johan Lindstrm, C<< <johanl[T]DarSerMan.com> >>
+Johan Lindstrom, C<< <johanl [AT] cpan.org> >>
 
 
 
@@ -305,7 +302,7 @@ suite.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2007 Johan Lindstrm, All Rights Reserved.
+Copyright 2007 Johan Lindstrom, All Rights Reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
